#include <robot_dart/robot_dart_simu.hpp>

#ifdef GRAPHIC
#include <robot_dart/gui/magnum/graphics.hpp>
#endif

/// namespace alias for ease of use
namespace rd = robot_dart;

int main()
{
    /// Create simulator object
    rd::RobotDARTSimu simu(0.001);

    /// Load our new robot
    auto robot = std::make_shared<rd::Robot>("double_pendulum.urdf");
    simu.add_robot(robot);

    /// Create graphics
#ifdef GRAPHIC
    rd::gui::magnum::GraphicsConfiguration gconfig;
    gconfig.width = 1024;
    gconfig.height = 768;
    auto graphics = std::make_shared<rd::gui::magnum::Graphics>(gconfig);
    simu.set_graphics(graphics);
    graphics->look_at({0., 3., 2.}, {0., 0., 0.}); // position_of_the_camera, point_to_look_at
#endif

    /// Fix robot to world frame
    robot->fix_to_world();

    /// Initial positions to allow falling
    robot->set_positions(rd::make_vector({0.00001, 0.}));

    /// Run simulation
    while (true) {
        if (simu.step_world())
            break;
    }

    return 0;
}
