#include <robot_dart/robot_dart_simu.hpp>

#ifdef GRAPHIC
#include <robot_dart/gui/magnum/graphics.hpp>
#endif

/// namespace alias for ease of use
namespace rd = robot_dart;

int main()
{
    /// Load a robot with packages
    std::vector<std::pair<std::string, std::string>> packages = {{"franka_description", "franka/franka_description"}};
    auto robot = std::make_shared<rd::Robot>("franka/franka.urdf", packages);
    robot->set_color_mode("material");

    // pin the arm to world
    robot->fix_to_world();
    robot->set_position_enforced(true);
    robot->set_actuator_types("servo");

    /// set initial joint positions
    auto positions = robot->positions();
    positions[5] = M_PI / 2.0;
    positions[7] = 0.04;
    positions[8] = 0.04;
    robot->set_positions(positions);

    /// Create simulator object
    rd::RobotDARTSimu simu(0.001);
    // we need the FCL collision detector for mesh collisions
    simu.set_collision_detector("fcl");

    /// Create graphics
#ifdef GRAPHIC
    rd::gui::magnum::GraphicsConfiguration gconfig;
    gconfig.width = 1024;
    gconfig.height = 768;
    auto graphics = std::make_shared<rd::gui::magnum::Graphics>(gconfig);
    simu.set_graphics(graphics);
    graphics->look_at({3., 1., 2.}, {0., 0., 0.}); // position_of_the_camera, point_to_look_at
#endif

    /// Add robot and nice floor ##########
    simu.add_robot(robot);
    simu.add_checkerboard_floor();

    /// Run simulation
    while (true) {
        if (simu.step_world())
            break;
    }

    return 0;
}
