import numpy as np
import RobotDART as rd
import dartpy # OSX breaks if this is imported before RobotDART

########## Create simulator object ##########
time_step = 0.001
simu = rd.RobotDARTSimu(time_step)

########## Create Graphics ##########
graphics = rd.gui.Graphics()
simu.set_graphics(graphics)
graphics.look_at([0., 2., 1.], [0., 0., 0.])

########## Create robot ##########
robot = rd.Robot("arm.urdf")
robot.set_position_enforced(True) # If True, limits of joints are not violated
robot.fix_to_world()
robot.set_actuator_types("servo")
robot.set_positions([0., np.pi/3., np.pi/4., -np.pi/2.])
# robot.set_positions([np.pi/6., np.pi/3., -np.pi/4., np.pi/2.])
body_names = robot.body_names()
print(body_names)
robot.set_draw_axis(robot.body_name(0), 0.5)
robot.set_draw_axis(robot.body_name(len(body_names)-1), 0.25)
simu.add_robot(robot)

########## Add floor ##########
simu.add_floor()


########## Analytical Forward Kinematics ##########
L0 = 0.0545
L1 = 0.123
L2 = 0.317
L3 = 0.202
L4 = 0.1605

joints = robot.positions()

tf_01 = dartpy.math.Isometry3()
tf_01.set_rotation(dartpy.math.eulerZYXToMatrix([joints[0], 0., 0.]))
tf_01.set_translation([0., 0., L0])

tf_12 = dartpy.math.Isometry3()
tf_12.set_rotation(dartpy.math.eulerZYXToMatrix([0., joints[1], 0.]))
tf_12.set_translation([0., 0., L1])

tf_23 = dartpy.math.Isometry3()
tf_23.set_rotation(dartpy.math.eulerZYXToMatrix([0., joints[2], 0.]))
tf_23.set_translation([0., 0., L2])

tf_34 = dartpy.math.Isometry3()
tf_34.set_rotation(dartpy.math.eulerZYXToMatrix([0., joints[3], 0.]))
tf_34.set_translation([0., 0., L3])

tf_45 = dartpy.math.Isometry3()
tf_45.set_rotation(dartpy.math.eulerZYXToMatrix([0., 0., 0.]))
tf_45.set_translation([0., 0., L4])

tf = tf_01.multiply(tf_12).multiply(tf_23).multiply(tf_34).multiply(tf_45)
print("Analytical:")
print(tf)

########## robot_dart Forward Kinematics ##########
print("robot_dart:")
print(robot.body_pose("arm_link_5"))

########## Run simulation ##########
while True:
    if simu.step_world():
        break
