import numpy as np
import RobotDART as rd
import dartpy # OSX breaks if this is imported before RobotDART

########## Create simulator object ##########
simu = rd.RobotDARTSimu(0.001)

########## Load our new robot ##########
robot = rd.Robot("double_pendulum.urdf") # double_pendulum.urdf should be in the running directory
simu.add_robot(robot)

########## Create Graphics ##########
gconfig = rd.gui.GraphicsConfiguration(1024, 768) # Create a window of 1024x768 resolution/size
graphics = rd.gui.Graphics(gconfig) # create graphics object with configuration
simu.set_graphics(graphics)
graphics.look_at([0., 3., 2.], [0., 0., 0.])

########## Fix robot to world frame ##########
robot.fix_to_world()

########## Initial positions to allow falling ##########
robot.set_positions([0.00001, 0.])

########## Run simulation ##########
while True:
    if simu.step_world():
        break
