import numpy as np
import RobotDART as rd
from utils import damped_pseudoinverse

# Load a robot
robot = rd.Arm()
robot.fix_to_world()
# Give some initial joint positions
robot.set_positions([-np.pi/2., np.pi/3., 1., np.pi/2.])

# Get Jacobian
J = robot.jacobian("arm_link_5")
print(J)

# Get Pseudoinverse of Jacobian
J_pinv = np.linalg.pinv(J)
print(J_pinv)

# DOF of robot less than 6, so J_pinv*J=I
print(J_pinv @ J) # this should be the identity matrix

# Get damped pseudoinverse of Jacobian (more stable in practical application)
J_dpinv = damped_pseudoinverse(J, 0.0001)
print(J_dpinv)

# DOF of robot less than 6, so J_pinv*J=I
print(J_dpinv @ J) # this should be the identity matrix
